@@ -3,8 +3,10 @@
 
 class TipoDeCampo(object):
     texto = "CharField"
+    area = "TextArea"
     boleano = "BooleanField"
     escolha = "ChoiceField"
+    decimal = "BRDecimalField"
 
 
 class CampoFormulario(object):
@@ -76,5 +78,16 @@ class ValoresBase(FormularioBase):
                 'valor': self.model.ativo
             }
         }
-        self_dict.update({field: {"campo": self.fields[field].nome, "valor": getattr(self.model, self.fields[field].nome)} for field in self.fields if self.fields[field].bound})
+        self_dict.update({field: {"campo": self.fields[field].nome, "valor": self.obtem_valor_serializavel(field)} for field in self.fields if self.fields[field].bound})
         return self_dict
+
+    def obtem_valor_serializavel(self, field):
+        valor = getattr(self.model, self.fields[field].nome)
+        if self.fields[field].tipo == TipoDeCampo.decimal:
+            valor = '{0:.2f}'.format(valor)
+        return valor
+
+
+class CadastroBase(object):
+    def __init__(self, configuracao):
+        self.configuracao = configuracao
\ No newline at end of file
