@@ -58,7 +58,7 @@ class EnviarPedido(Plugavel):
 
     def post(self, segunda_tentativa=False):
         conexao = Conexao(self.meio_pagamento, self.configuracao_pagamento, self.requisicao, TipoConexao.envio, self.processar_resposta)
-        return conexao.get(segunda_tentativa)
+        return conexao.post(segunda_tentativa)
 
     def enviar(self):
         resultado = self.post()
