@@ -25,6 +25,10 @@ class Credenciador(object):
     def esta_valido(self):
         return True
 
+    @property
+    def chave(self):
+        return "access_token"
+
 
 class TipoAutenticacao(object):
     cabecalho_http = 1
@@ -40,6 +44,7 @@ class TipoMetodo(object):
     get = "get"
     post = "post"
 
+
 class Credenciais(base.Plugavel):
     def __init__(self, meio_pagamento, configuracao_pagamento):
         self.meio_pagamento = meio_pagamento
@@ -70,9 +75,9 @@ class Credenciais(base.Plugavel):
     def esta_valido(self):
         return self.credenciador.esta_valido()
 
-    def por_query_string(self, chave="access_token"):
+    def por_query_string(self):
         try:
-            return "{}={}".format(chave, self.credenciador.obter_credenciais())
+            return "{}={}".format(self.credenciador.chave, self.credenciador.obter_credenciais())
         except AttributeError:
             raise CredenciadorInvalido(u"O credenciador {}.{} não implementa o método obter_credenciais(credenciamento=None).".format(self.credenciador.__module__, self.credenciador.__class__.__name__))
 
@@ -90,6 +95,8 @@ class Conexao(object):
         self.configuracao_pagamento = configuracao_pagamento
         self.servico = servico
         self.headers = {"Content-Type": "application/json"}
+        if hasattr(servico, "headers"):
+            self.headers = servico.headers
         self.processar_resposta = processar_resposta
 
     def define_url_com_autenticacao(self, atualiza_autenticacao=False):
@@ -110,9 +117,12 @@ class Conexao(object):
         if hasattr(self.servico, "dados"):
             dados = self.servico.dados
             dados_envio = dados
+        if self.servico.envio_por_querystring:
+            resposta = getattr(requests, metodo)(url, params=dados_envio, headers=self.headers)
+        else:
             if type(dados is dict):
                 dados_envio = json.dumps(dados)
-        resposta = getattr(requests, metodo)(url, data=dados_envio, headers=self.headers)
+            resposta = getattr(requests, metodo)(url, data=dados_envio, headers=self.headers)
         if self.processar_resposta:
             resposta = self.processar_resposta(resposta)
         if settings.GRAVA_EVIDENCIA and self.tipo == TipoConexao.envio:
